==> nextcloud-13.0.1.tgz: nextcloud/apps/updatenotification/l10n/ca.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Hi ha disponible la versió {version}. Obtingueu més informació sobre com actualitzar.",
    "Open updater" : "Obrir actualitzador",
    "Your version is up to date." : "La teva versió està actualitzada.",
    "A non-default update server is in use to be checked for updates:" : "S'utilitza un servidor d'actualització no predeterminat per comprovar si hi ha actualitzacions:",
    "Update channel:" : "Actualitzar canal:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Sempre podràs actualitzar a una versió més recent / canal experimental. Però mai es pot fer un \"downgrade\" a un canal més estable.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Tingueu en compte que després d'un nou llançament, pot trigar un temps abans que aparegui aquí. Desplegem noves versions distribuïdes amb el temps als nostres usuaris i, de vegades, ometen una versió quan es detecten problemes.",
    "Notify members of the following groups about available updates:" : "Notificar als membres dels següents grups sobre les actualitzacions disponibles:",
    "Only notification for app updates are available." : "Només notificació d'actualitzacions d'apps estan disponibles.",
    "The selected update channel does not support updates of the server." : "El canal d'actualització seleccionat no admet actualitzacions del servidor.",
    "Could not start updater, please try the manual update" : "No s'ha pogut iniciar actualitzador, provi l'actualització manual",
    "Update notifications" : "Notificacions d'actualització",
    "Channel updated" : "Canal actualitzat",
    "The update server could not be reached since %d days to check for new updates." : "El servidor d'actualització no es va poder arribar des %d dies per comprovar si hi ha noves actualitzacions.",
    "Please check the Nextcloud and server log files for errors." : "Si us plau, comproveu els fitxers de log del servidor i de Nextcloud per detectar errors.",
    "Update to %1$s is available." : "Actualització per %1$s està disponible.",
    "Update for %1$s to version %2$s is available." : "L'actualització per %1$s a la versió %2$s està disponible.",
    "Update for {app} to version %s is available." : "Actualització per {app} a la versió %s està disponible.",
    "Update notification" : "Notificació d'actualització",
    "A new version is available: %s" : "Una nova versió està disponible: %s",
    "Download now" : "Descarrega ara",
    "Checked on %s" : "Comprovat en %s",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal d'actualització seleccionat deixa obsoletes les notificacions específiques del servidor.",
    "The update check is not yet finished. Please refresh the page." : "Actualitzeu la pàgina."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/updatenotification/l10n/ca.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Hi ha disponible la versió {version}. Obtingueu més informació sobre com actualitzar.",
    "Update notifications" : "Notificacions d'actualització",
    "Channel updated" : "Canal actualitzat",
    "The update server could not be reached since %d days to check for new updates." : "El servidor d'actualització no es va poder arribar des %d dies per comprovar si hi ha noves actualitzacions.",
    "Please check the Nextcloud and server log files for errors." : "Si us plau, comproveu els fitxers de log del servidor i de Nextcloud per detectar errors.",
    "Update to %1$s is available." : "Actualització per %1$s està disponible.",
    "Update for %1$s to version %2$s is available." : "L'actualització per %1$s a la versió %2$s està disponible.",
    "Update for {app} to version %s is available." : "Actualització per {app} a la versió %s està disponible.",
    "Update notification" : "Notificació d'actualització",
    "Open updater" : "Obrir actualitzador",
    "What's new?" : "Què hi ha de nou?",
    "The update check is not yet finished. Please refresh the page." : "Actualitzeu la pàgina.",
    "A non-default update server is in use to be checked for updates:" : "S'utilitza un servidor d'actualització no predeterminat per comprovar si hi ha actualitzacions:",
    "Update channel:" : "Actualitzar canal:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Sempre podràs actualitzar a una versió més recent / canal experimental. Però mai es pot fer un \"downgrade\" a un canal més estable.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Tingueu en compte que després d'un nou llançament, pot trigar un temps abans que aparegui aquí. Desplegem noves versions distribuïdes amb el temps als nostres usuaris i, de vegades, ometen una versió quan es detecten problemes.",
    "Notify members of the following groups about available updates:" : "Notificar als membres dels següents grups sobre les actualitzacions disponibles:",
    "Only notification for app updates are available." : "Només notificació d'actualitzacions d'apps estan disponibles.",
    "The selected update channel does not support updates of the server." : "El canal d'actualització seleccionat no admet actualitzacions del servidor.",
    "View changelog" : "Mostra el registre de canvis",
    "Could not start updater, please try the manual update" : "No s'ha pogut iniciar actualitzador, provi l'actualització manual",
    "A new version is available: %s" : "Una nova versió està disponible: %s",
    "Download now" : "Descarrega ara",
    "Your version is up to date." : "La teva versió està actualitzada.",
    "Checked on %s" : "Comprovat en %s",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal d'actualització seleccionat deixa obsoletes les notificacions específiques del servidor."
},
"nplurals=2; plural=(n != 1);");
